@@ -124,13 +124,20 @@ discoverer_discovered_cb (GstDiscoverer *disco,
 {
   SushiSoundPlayer *player = user_data;
   SushiSoundPlayerPrivate *priv;
+  const GstTagList *taglist;
+
   priv = SUSHI_SOUND_PLAYER_GET_PRIVATE (player);
 
   if (error != NULL)
     return;
 
-  priv->taglist = gst_tag_list_copy (gst_discoverer_info_get_tags (info));
-  g_object_notify (G_OBJECT (player), "taglist");
+  taglist = gst_discoverer_info_get_tags (info);
+
+  if (taglist)
+    {
+      priv->taglist = gst_tag_list_copy (taglist);
+      g_object_notify (G_OBJECT (player), "taglist");
+    }
 }
 
 static gboolean
@@ -285,16 +292,12 @@ static void
 sushi_sound_player_query_duration (SushiSoundPlayer *player)
 {
   SushiSoundPlayerPrivate *priv;
-  GstFormat format = GST_FORMAT_TIME;
   gdouble new_duration, difference;
-  gboolean success;
   gint64 duration;
 
   priv = SUSHI_SOUND_PLAYER_GET_PRIVATE (player);
 
-  success = gst_element_query_duration (priv->pipeline, &format, &duration);
-
-  if (G_UNLIKELY (success != TRUE))
+  if (!gst_element_query_duration (priv->pipeline, GST_FORMAT_TIME, &duration))
     return;
 
   new_duration = (gdouble) duration / GST_SECOND;
@@ -694,11 +697,7 @@ sushi_sound_player_set_property (GObject      *gobject,
                                  const GValue *value,
                                  GParamSpec   *pspec)
 {
-  SushiSoundPlayer *player;
-  SushiSoundPlayerPrivate *priv;
-  
-  player = SUSHI_SOUND_PLAYER (gobject);
-  priv = SUSHI_SOUND_PLAYER_GET_PRIVATE (player);
+  SushiSoundPlayer *player = SUSHI_SOUND_PLAYER (gobject);
 
   switch (prop_id)
     {
@@ -799,8 +798,6 @@ sushi_sound_player_class_init (SushiSoundPlayerClass *klass)
 static void
 sushi_sound_player_init (SushiSoundPlayer *player)
 {
-  SushiSoundPlayerPrivate *priv;
-
   player->priv = SUSHI_SOUND_PLAYER_GET_PRIVATE (player);
 
   player->priv->state = SUSHI_SOUND_PLAYER_STATE_UNKNOWN;
